# Changelog

All notable changes to the Django Hierarchical Models package will be documented in this file.

## [0.1.1] - 2024-03-24

### Added
- Added support for Django 5.0 and 5.1
- Added Python 3.12 to test matrix (Django 4.0+ only)

### Changed
- Updated GitHub Actions workflow to use latest action versions
- Improved documentation site with GitHub Pages styling

## [0.1.0] - 2024-03-24

### Added
- Initial version of the package with hierarchical model inheritance
- Support for regular fields and ManyToMany fields
- Admin integration with `HierarchicalModelAdmin`
- Initial documentation 